@@ -1,25 +1,7 @@
 r"""
 Sak is a simple, powerful and clean python common function library.
 
-Git: https://git.keyboardman.fun/keyboardman/Sak
-
-常量
-    SakUserPlatform （系统信息）
-
-模块
-    config (配置项)
-
-    debug (调试相关)
-
-    file (文件相关)
-
-    img (图片相关)
-
-    MyThread (线程相关)
-
-    path (路径相关)
-
-    time (时间相关)
+Github: https://github.com/1Gbps/pysak
 """
 
 SakUserPlatform = None
